@@ -83,7 +83,7 @@ setMethod("skewness", signature(x = "Chisq"),
     })
 #
 setMethod("skewness", signature(x = "Dirac"),
-    function(x){return(0)})
+    function(x, ...){return(0)})
 
 #
 setMethod("skewness", signature(x = "DExp"),
@@ -232,6 +232,12 @@ setMethod("skewness", signature(x = "Beta"),
         return( 2*(b-a)*sqrt(a+b+1)/(a+b+2)/sqrt(a*b) ) }
     })
 
+###################################################################################
+#skewness --- code P.R.:
+###################################################################################
+
+setMethod("skewness", signature(x = "Arcsine"),
+    function(x, ...)return(0))
 
 
 
